//////////////////////////////////////////////////////////////////////
//
//  XBPGET.CH
//
//  Copyright:
//     Ashok Kumar
//  
//  Contents:
//     Clipper @..SAY..GET implementation
//  
//  Remarks:
//     Converts Clipper's @..SAY into XBPStatics
//     Converts Clipper's @..GET into XBPSle
//  
//////////////////////////////////////////////////////////////////////

#include "std.ch"
#include "common.ch"

#include "Inkey.ch"
#include "Gra.ch"
#include "Xbp.ch"
#include "Appevent.ch"
#include "Font.ch"


*******************************************************************************
* Command: @...SAY
* Changed: AK 13/4/98
*******************************************************************************

#command  @ <nRow>, <nCol> SAY <say> [PICTURE <pic>] [COLOR <Color>] ;
      =>  AK_say(<nRow>, <nCol>, <say>, <pic> )

#command  @ <nRow>, <nCol> SAY <say> [COLOR <Color>] ;
      =>  AK_say(<nRow>, <nCol>, <say>)

*******************************************************************************
* Command: @...GET
* Changed: AK 15/4/98
*******************************************************************************

#command  @ <nRow>, <nCol> GET <Var> ;
                      [PICTURE <cPict>] ;
                        [VALID <lValid>] ;
                         [WHEN <lWhen>] ;
                         [SEND <message>] ;

      => If Type(Alias() + "->" + <"Var">) # "U" ;;
            AK_get(<nRow>, <nCol>, Alias()+"->"+<"Var"> , <cPict>, <"lValid">, <"lWhen"> );;
         Else ;;
            AK_get(<nRow>, <nCol>, <"Var">, <cPict>, <"lValid">, <"lWhen"> );;
         EndIf


// With HIDDEN clause for passwords
#command  @ <nRow>, <nCol> GET <Var> ;
                      [PICTURE <cPict>] ;
                        [VALID <lValid>] ;
                         [WHEN <lWhen>] ;
                         [SEND <message>] ;
                         HIDDEN ;

      => If Type(Alias() + "->" + <"Var">) # "U" ;;
            AK_get(<nRow>, <nCol>, Alias()+"->"+<"Var"> , <cPict>, <"lValid">, <"lWhen">, .T. );;
         Else ;;
            AK_get(<nRow>, <nCol>, <"Var">, <cPict>, <"lValid">, <"lWhen">, .T. );;
         EndIf

*******************************************************************************
* Command: @...SAY...GET
*******************************************************************************

#command  @ <nRow>, <nCol> SAY <Say> [<sayOptions,...>] ;
                           GET <Var> [<getOptions,...>] ;
      =>  @ <nRow>, <nCol> SAY <Say> [<sayOptions>] ;;
          @ row(), col()+1 GET <Var> [<getOptions>]

*******************************************************************************
* Command: @...GET...RANGE (is translated to @...GET...VALID)
* Changed: AK 15/4/98
*******************************************************************************

#command  @ <nRow>, <nCol> GET <Var> [<Options,...>] ;
                         RANGE <low>, <high> [<moreOptions,...>] ;
      =>  @ <nRow>, <nCol> GET <Var> [<Options>] ;
                         VALID ( <Var> >=  <low> .and. <Var> <= <high> ) ;
                         [<moreOptions>]

*******************************************************************************
* Command: @...GET...COLOR
*******************************************************************************

#command  @ <nRow>, <nCol> GET <Var>    [<Options,...>] ;
                         COLOR <cColor> [<moreOptions,...>] ;
      =>  @ <nRow>, <nCol> GET <Var>    [<Options>] ;
                          SEND colorDisp(<cColor>) [<moreOptions>]

*******************************************************************************
* Commands: READ, READ SAVE, CLEAR GETS
* Changed: AK 15/4/98
*******************************************************************************

#command READ SAVE          => ReadModal(getList)
*** #command READ               => ReadModal(getList) ; getList := {}
#command CLEAR GETS         => ReadKill(.T.) ; ;
                               AEval( getlist, { |oXbp| oXbp:Destroy() } ) ;;
                               getlist := {}

#command CLEAR SAYS         => AEval( saylist, { |oXbp| oXbp:Destroy() } ) ; saylist := {}

#command  CLEAR ;
      =>  CLEAR SCREEN ;;
          CLEAR GETS ;;
          CLEAR SAYS


* Use these CLEAR SAYS if you want to use XBPStatics
* Changed: AK 14/4/98
#command  CLS ;
      =>  Scroll() ; SetPos(0,0) ; CLEAR SAYS

#command  CLEAR SCREEN ;
      =>  Scroll() ; SetPos(0,0) ; CLEAR SAYS

#command  @ <nT>, <nL> ;
      =>  Scroll(<nT>, <nL>, <nT>) ; SetPos(<nT>, <nL>) ; CLEAR SAYS

#command  @ <nT>, <nL> CLEAR ;
      =>  Scroll(<nT>, <nL>) ; SetPos(<nT>, <nL>) ; CLEAR SAYS

#command  @ <nT>, <nL> CLEAR TO <nB>, <nR> ;
      =>  Scroll(<nT>, <nL>, <nB>, <nR>) ; SetPos(<nT>, <nL>) ; CLEAR SAYS


#command READ ;

      => if len(getlist) > 0;                                   ;
            Scatter( getlist );                                 ;
            SetAppFocus( getlist\[AK_GetNext(1, .F. )\] );      ;
            nEvent := xbe_None;                                 ;
            DO WHILE nEvent <> xbeP_Close;                      ;
               nEvent := AppEvent( @mp1, @mp2, @oXbp );         ;
               oXbp:handleEvent( nEvent, mp1, mp2 );            ;
            ENDDO;                                              ;
            CLEAR GETS ;                                        ;
         ENDIF


#translate GetActive()   => oXbp:Get

#command DISABLE GETS    => AEval( getlist, { |oXbp| oXbp:SetData(),oXbp:disable() } )

//////////////////////////////////////////////////////////////////////

